#
# spec file for package mumble
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2025 Andreas Stieger <Andreas.Stieger@gmx.de>
# Copyright (c) 2024 Tobias Burnus <burnus@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# on Tumbleweed with gcc15, TestSSLLocks::stress() time out on aarch64 and i586
%ifarch x86_64
%bcond_without tests
%else
%bcond_with tests
%endif
%bcond_without server
Name:           mumble
Version:        1.5.735
Release:        2.2
Summary:        Voice Communication Client for Gamers
# Most files are BSD-3-Clause
# 3rdparty/arc4random/LICENSE: MIT
# 3rdparty/SPSCQueue: MIT
# 3rdparty/flag-icons: MIT
License:        BSD-2-Clause AND BSD-3-Clause AND MIT
Group:          Productivity/Multimedia/Sound/Utilities
URL:            https://www.mumble.info/
Source:         %{name}-%{version}.tar.xz
Source6:        baselibs.conf
# PATCH-FIX-UPSTREAM fix-64bit-only-plugins.patch -- Requires 64bit memory alignment ( https://github.com/mumble-voip/mumble/issues/5849 )
Patch0:         fix-64bit-only-plugins.patch
# PATCH-FIX-UPSTREAM mumble-1.5.735-fix-gcc15.patch -- fix build with gcc15 https://github.com/mumble-voip/mumble/pull/6775
Patch1:         mumble-1.5.735-fix-gcc15.patch
# Patches related to dependency unbundling
Patch100:       licenses.patch
Patch101:       mumble-unbundle-tracy.patch
Patch103:       mumble-1.5.629-unbundle-audio-backends.patch
BuildRequires:  c++_compiler
BuildRequires:  cmake >= 3.20
BuildRequires:  libboost_headers-devel
BuildRequires:  pkgconfig
BuildRequires:  cmake(Microsoft.GSL)
BuildRequires:  cmake(PocoXML)
BuildRequires:  cmake(PocoZip)
BuildRequires:  cmake(Qt5Concurrent)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5Sql)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5TextToSpeech)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5Xml)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(avahi-compat-libdns_sd)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(libpcre2-posix)
BuildRequires:  pkgconfig(libpipewire-0.3)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libssl)
BuildRequires:  pkgconfig(nlohmann_json)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(portaudio-2.0)
BuildRequires:  pkgconfig(speech-dispatcher)
BuildRequires:  pkgconfig(speexdsp)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(zlib)
%if %{with tests}
BuildRequires:  cmake(Qt5Test)
%endif
%if %{with server}
BuildRequires:  pkgconfig(libcap)
%endif
%if 0%{?suse_version} <= 1550
BuildRequires:  protobuf-devel
%else
BuildRequires:  cmake(protobuf)
%endif
%if 0%{?suse_version} > 1600
BuildRequires:  cmake(SndFile)
%else
BuildRequires:  libsndfile-devel
%endif
%ifarch x86_64
BuildRequires:  gcc-c++-32bit
Recommends:     %{name}-32bit
Conflicts:      %{name}-32bit < %{version}
%endif
%ifarch ppc
Recommends:     %{name}-64bit
Conflicts:      %{name}-64bit < %{version}
%endif

%description
Low-latency, high-quality voice communication for gamers. Includes game
linking, so voice from other players comes from the direction of their
characters, and has echo cancellation so the sound from your loudspeakers
won't be audible to other players.

%if %{with server}
%package server
Summary:        Voice Communication Server for Gamers
Group:          Productivity/Multimedia/Sound/Utilities
Requires:       lsb-release
Recommends:     libQt5Sql5-mysql
Recommends:     libQt5Sql5-postgresql
Recommends:     libQt5Sql5-sqlite
%{?systemd_requires}

%description server
Low-latency, high-quality voice communication for gamers. Includes game
linking, so voice from other players comes from the direction of their
characters, and has echo cancellation so the sound from your loudspeakers
won't be audible to other players.
%endif

%prep
%autosetup -p1

%build
%cmake \
%if %{with server}
	-Dserver:BOOL=ON \
	-Dice:BOOL=OFF \
%else
	-Dserver:BOOL=OFF \
%endif
	-Dupdate:BOOL=OFF \
	-Dcrash-report:BOOL=OFF \
	-Ddisplay-install-paths:BOOL=ON \
	-Doverlay-xcompile:BOOL=OFF \
	-Dsymbols:BOOL=ON \
	-DMUMBLE_INSTALL_PLUGINDIR=%{_libdir}/mumble/plugins \
	-Dbundled-gsl:BOOL=OFF \
	-Dbundled-json:BOOL=OFF \
	-Dbundled-renamenoise:BOOL=ON \
	-Dbundled-speex:BOOL=OFF \
	-Dqtspeech:BOOL=ON \
	-Dbundle-qt-translations:BOOL=OFF \
%if 0%{?suse_version} > 1600
	-DCMAKE_SHARED_LINKER_FLAGS="-lGL" \
%endif
%if 0%{?suse_version} <= 1550
	-DCMAKE_MODULE_LINKER_FLAGS="" \
	-DCMAKE_SHARED_LINKER_FLAGS="" \
%endif
%if %{with tests}
	-Dtests:BOOL=ON \
%endif
	-DCMAKE_CXX_STANDARD=17 \
	-Dwarnings-as-errors:BOOL=OFF \
%{nil}

%cmake_build

%install
%cmake_install

mkdir -p %{buildroot}%{_docdir}/%{name}
cp -a scripts README.md %{buildroot}%{_docdir}/%{name}
find %{buildroot}%{_docdir}/%{name}/scripts -type f -name '*.py' -exec chmod -x {} \;
find %{buildroot}%{_docdir}/%{name}/scripts -type f -name '*.rb' -exec chmod -x {} \;
find %{buildroot}%{_docdir}/%{name}/scripts -type f -name '*.sh' -exec chmod -x {} \;
find %{buildroot}%{_docdir}/%{name}/scripts -type f -name '*.bat' -exec chmod -x {} \;

%if %{with server}
# This was messed up by https://github.com/mumble-voip/mumble/pull/6100
# I wasted enough time trying to patch this, so this is brute force
# Also see -Ddisplay-install-paths and output of cmake
mkdir -p %{buildroot}%{_sysconfdir}/mumble
mkdir -p %{buildroot}%{_unitdir}
mkdir -p %{buildroot}%{_sysusersdir}
mv -v %{buildroot}%{_prefix}%{_sysconfdir}/mumble/mumble-server.ini %{buildroot}%{_sysconfdir}/mumble/mumble-server.ini
mv -v %{buildroot}%{_prefix}%{_sysconfdir}/systemd/system/mumble-server.service %{buildroot}%{_unitdir}/mumble-server.service
mv -v %{buildroot}%{_prefix}%{_sysconfdir}/sysusers.d/mumble-server.conf %{buildroot}%{_sysusersdir}/mumble-server.conf
# z not authorized and not required
rm %{buildroot}%{_prefix}%{_sysconfdir}/tmpfiles.d/mumble-server.conf
# fix path in service
sed -i -e 's|%{_prefix}%{_sysconfdir}|%{_sysconfdir}|g' %{buildroot}%{_unitdir}/mumble-server.service
%endif

%check
%if %{with tests}
# TestSettingsJSONSerialization fails loading qt xcb in headless
export QT_QPA_PLATFORM=offscreen
%ctest
%endif

%if %{with server}
%pre server
%service_add_pre mumble-server.service

%preun server
%service_del_preun mumble-server.service

%post server
%service_add_post mumble-server.service

%postun server
%service_del_postun mumble-server.service
%endif

%files
%license LICENSE
%doc %{_docdir}/%{name}
%{_bindir}/mumble
%{_bindir}/mumble-overlay
%{_mandir}/man1/mumble-overlay.1%{?ext_man}
%{_mandir}/man1/mumble.1%{?ext_man}
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/*
%dir %{_datadir}/icons/hicolor/*/apps
%{_datadir}/icons/hicolor/*/apps/mumble.*
%{_datadir}/applications/*
%{_libdir}/mumble
%{_datadir}/metainfo/info.mumble.Mumble.appdata.xml

%if %{with server}
%files server
%license LICENSE
%{_bindir}/mumble-server
%{_bindir}/mumble-server-user-wrapper
%dir %{_sysconfdir}/mumble
%config(noreplace) %{_sysconfdir}/mumble/mumble-server.ini
%{_unitdir}/mumble-server.service
%{_sysusersdir}/mumble-server.conf
%{_mandir}/man1/mumble-server.1%{?ext_man}
%{_mandir}/man1/mumble-server-user-wrapper.1%{?ext_man}
%endif

%changelog
* Thu Jun 26 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Fix build with gcc15 (boo#1245428):
  * add mumble-1.5.735-fix-gcc15.patch
  * disable warnings-as-errors, see PR#6517 upstream
* Sun Dec  8 2024 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 1.5.735:
  * TRANSLATION: Backport translations
  * CI(appveyor): Workaround for FXC failing to run with error C0000139
  * DOCS(server): Add Documentation key to mumble-server unit
  * FIX(cmake): Ensure the client installer target is built after its dependencies
  * FIX(cmake): Don't set WORKING_DIRECTORY for ExternalProject_Add()
  * TRANSLATION: Backport translations
  * FIX(client): Fix AudioWizard echo cancellation checkbox
  * FIX(client): Use correct off audio cue
  * FIX(plugins): Load correct pages for modules
  * FIX(client): Limit size of the chat bar
  * FIX(client): Save local volume adjustment when clicking slider bar
  * FIX(client): Prevent sending plain text on fast CTRL+V + ENTER
  * TRANSLATION: Update translation files
  * FIX(client): Replace dead URL in Certificate Wizard
  * TRANSLATION: Update translation files
  * FIX(client): Remove mention of the Mumble wiki
  * MAINT: Remove mentions of the Mumble wiki
  * FIX(server): Change server thread name to "mumble-server" instead of "Main"
  * FIX(client, server): Remove redundant OpenSSL locking callback check
  * BUILD: Fix compiler warnings on 32bit architectures
  * FIX(client): Fix crash on mono pos. audio warning from audio thread
  * BUILD: Disable MSVC 17.8 warning for stdext::checked_array_iterator
  * CI(cirrus): Disable warnings-as-errors for the 1.5.x branch
  * CI(cirrus): Install "ice37" package instead of "ice"
  * FIX(client, plugins): Wrong sample count in plugin callback
  * MAINT: Update backport config
  * MAINT: Only run backport action when PR is merged
  * FIX(client): Do not spam log when adjusting volume of clients without certificate
  * FIX(client): Update tab order in AudioInput.ui
  * BUILD: Use correct type for num locks
  * FIX(client): Do not duplicate group name in ACLEditor combobox
  * FIX(a11y): In ACLEditor make space popup the combobox list
  * FIX(client): In ACLEditor apply changes to group or user on lost focus
  * FIX(server): Allow to move temporary channels provided sufficient permissions
  * REFAC(client): Use ellipsis character ("…") instead of three dots ("...") in elideText
  * FIX(client): Remove placeholder wrapping in ChatBar
  * FIX(client): Improve handling of the GlobalShortcutButtons dialog
  * FIX(client): Correctly remember muted state across restarts
  * FIX(client): Capture "this" explicitly in lambdas
  * FIX(client): Crash when loading settings
* Mon May 20 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.5.634:
  * first stable release in the 1.5.x series
  * flag icons replaced with an MIT licensed version
- replace mumble-cxx17.patch with a cmake option
- drop mumble-1.5.629-The-OCB-design-is-in-the-public-domain.patch
  now upstream
* Thu Apr 25 2024 Andreas Stieger <andreas.stieger@gmx.de>
- enable and fix tests: TestSettingsJSONSerialization fails loading
  qt xcb in headless
* Tue Apr 23 2024 Andreas Stieger <andreas.stieger@gmx.de>
- Address licensedigger concerns:
  * drop qttranslations from tarball, adjust licenses.patch
  * The OCB design is in the public domain
    add mumble-1.5.629-The-OCB-design-is-in-the-public-domain.patch
  * drop unneeded installer files from tarball
  * unbundle audio back-end headers from tarball:
    pulseadio, jack, portadio, pipewire
    add mumble-1.5.629-unbundle-audio-backends.patch
- change from tarball to obscpio and build-time service
* Sat Apr 20 2024 Andreas Stieger <andreas.stieger@gmx.de>
- switch to source service generated tarball that has a number of
  unused, bundled libraries removed. Patch the sources to not
  require that they are present - add licenses.patch
* Sat Apr 20 2024 Andreas Stieger <andreas.stieger@gmx.de>
- mumble 1.5.629 (RC3)
  * ReNameNoise as a replacement for RNNoise
  * Accessibility across the entire application
  * Add ability to record MP3s
  * UI updates
  * bug fixes
- packaging changes:
  * use system libraries where available and clean up dependencies
  * move appdata to client package
  * remove usage of tracy - mumble-unbundle-tracy.patch
- drop patches:
  * fix-pkg_get_variable.patch - reworked upstream
  * mumble-1.5.517-qsystemlocaledate.patch - not needed
  * reproducible.patch - merged
  * mumble-leap-cxx17-filesystem.patch - not needed
* Thu Feb 22 2024 pgajdos@suse.com
- Use %%patch -P N instead of deprecated %%patchN.
* Thu Jan 25 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to sort the file list (boo#1041090)
* Thu Jan 18 2024 Andreas Stieger <andreas.stieger@gmx.de>
- Fix build with Qt 5.15 / OpenGL (boo#1218944)
- Fix mumble-server.service (gh#mumble-voip/mumble/6273)
* Thu Nov 23 2023 Andreas Stieger <andreas.stieger@gmx.de>
- enable pulseaudio support boo#1217419
* Sat Oct 28 2023 Andreas Stieger <andreas.stieger@gmx.de>
- simplify spec file and package license file
* Fri Oct 27 2023 Marguerite Su <i@marguerite.su>
- fix FTBFS (boo#1215996)
  * needs to build with CXX17 standard
  * QSystemLocaleDate is deprecated
  * <filesystem> sometimes must be <experimental/filesystem>
* Mon Apr 17 2023 Marcel Kuehlhorn <tux93@opensuse.org>
- Remove DBus service (boo#1209338)
* Mon Mar  6 2023 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.5.517
- Add fix-pkg_get_variable.patch to fix CMake not using the correct
  pkgconf variables, also needs BuildRequires: systemd
- Update fix-64bit-only-plugins.patch
- Use systemd-sysusers for user creation when available
- Update keyring
* Wed Sep 21 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 1.4.287:
  - Client
  * Fixed: Broken link targets with percent signs
  * Fixed: Don’t allow manual toggling of minimal view note
  * Fixed: Fallback path for themes
  * Fixed: Fix versions being transmitted incorrectly
    (with patch numbers > 255)
  * Fixed: Icon scale being way too small
  * Fixed: Make hiding UI elements (in custom layout) persistent
    again
  * Fixed: Resolve log text scaling issues
  - Server
  * Fixed: Fix versions being transmitted incorrectly
    (with patch numbers > 255)
- Add BuildRequires pcre2-devel for openSUSE Leap, fixes building
- Run spec-cleaner
* Thu Sep  1 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Add fix-64bit-only-plugins.patch to fix build on i586
* Sun Aug 21 2022 Enrico Belleri <idesmi@protonmail.com>
- Update to 1.4.274:
  - Client:
  * Changed: Disable RNNoise by default
  * Changed: Don’t hard block shortcuts on Wayland
  * Fixed: Context and identity not getting cleared
  * Fixed: Don’t display unsupported ACL
  * Fixed: Fix PipeWire not being usable in Flatpaks
  * Fixed: Icon not used on Plasma Wayland session
  * Fixed: Improve appstream metadata
  * Fixed: Minimal view not always working
  * Fixed: PFS information being incorrect
  * Fixed: Percent encoded links not clickable
  * Fixed: Prefer selected tree item for context menu creation
  * Fixed: Prevent endless loop when disconnecting PipeWire stream
  * Fixed: Register simultaneous mouse button presses separately
  * Fixed: Show friendlier text when displaying notifications
  * Fixed: Properly verify certificates when SRV records are used
  * Fixed: Resolve list tags, etc. polluting log
  * Fixed: Remove duplicate entry for “What’s this?” in UserModel
  * Fixed: User and channel status icons now take display scaling into account
  - Server:
  * Fixed: Add missing line breaks to –help output
  * Fixed: Improve rememberchannelduration compare logic
  * Fixed: Update suppress state on ACL change
  - Positional audio plugins:
  * Fixed: Fix Quake Live plugin
  * Fixed: Update Among Us plugin to work with v2022.3.29s (1864)
- Remove upstreamed:
  * 36398fb.patch
  * 73d8a4d5.patch
* Wed May 11 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Add 36398fb.patch from upstream to fix build with gcc 12
* Sun May  8 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Fix build with new poco version (1.11.2), added 73d8a4d5.patch
* Sat Apr 16 2022 Stefan Seyfried <seife+obs@b1-systems.com>
- do not include 32-bit libmumbleoverlay.x86.so in 64bit build
  (if you want to use that, install mumble-32bit additionally)
  boo#1198535
* Tue Jan 25 2022 Markus Ebner <info@ebner-markus.de>
- Update to Mumble 1.4.230
  * qmake build-system removed
  * New extended plugin framework
  * Support for stereo playback
  * Support for local naming (nicknames)
  * Markdown support for chat
  * UI indication for access restriction
  * New non-gaming oriented TalkingUI
  * Channel listeners
  * Search dialog for users in a server
- Cleanup of the specfile
  * Fixed source urls for changed scheme
  * Ported specfile to CMake build-system
  * Use cmake install instead of manual as much as possible
  * Disabled ICE for now (depends on unavailable lib)
  * Removed a lot of obsolete logical branches
  * bonjour is no longer optional
  * Removed init.d script and enabled systemd
* Wed Nov 10 2021 Mia Herkt <mia@0x0.st>
- Enable JACK support
* Thu Oct  7 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * mumble-server.service
* Fri Feb 12 2021 Andreas Stieger <andreas.stieger@gmx.de>
- mumble 1.3.4:
  * Fix use of outdated (non-existent) notification icon names
  * Fix Security vulnerability caused by allowing non http/https
    URL schemes in public server list (boo#1182123, CVE-2021-27229)
  * Server: Fix Exit status for actions like --version or --supw
  * Fix packet loss & audio artifacts caused by OCB2 XEX*
    mitigation
- update signing keyring
* Fri Dec 25 2020 Yaroslav Kurlaev <yaroslav.kurlaev@gmail.com>
- Don't edit categories of .desktop files.
  * Fixes boo#1180068
* Sat Oct 24 2020 Marcus Rueckert <mrueckert@suse.de>
- update apparmor profiles to get warning free again on 15.2
  - use abstractions for ssl files
  - allow inet dgram sockets as mumble can also work via udp
  - allow netlink socket (probably for dbus)
  - properly allow lsb_release again
  - add support for optional local include
- start murmurd directly as user mumble-server it gets rid of the
  dac_override/setgid/setuid/chown permissions
* Mon Oct  5 2020 Markus Ebner <info@ebner-markus.de>
- Update to upstream version 1.3.3
- Client
  * Fixed: Chatbox invisble (zero height) (#4388)
  * Fixed: Handling of invalid packet sizes (#4394)
  * Fixed: Race-condition leading to loss of shortcuts (#4430)
  * Fixed: Link in About dialog is now clickable again (#4454)
  * Fixed: Sizing issues in ACL-Editor (#4455)
  * Improved: PulseAudio now always samples at 48 kHz (#4449)
- Server
  * Fixed: Crash due to problems when using PostgreSQL (#4370)
  * Fixed: Handling of invalid package sizes (#4392)
* Wed Aug 19 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Consistently use %%{_tmpfilesdir} instead of abusing
  %%{_libexecdir}/tmpfiles.d.
* Sat Jul 11 2020 Andreas Stieger <andreas.stieger@gmx.de>
- mumble 1.3.2:
  * client: Fixed overlay not starting
- fetch upstream release signing key for 2020
* Fri Jun 19 2020 Markus Ebner <info@ebner-markus.de>
- Update to upstream version 1.3.1
- Security
  * Fixed: Potential exploit in the OCB2 encryption (#4227)
    boo#1174041
- ICE
  * Fixed: Added missing UserKDFIterations field to UserInfo =>
    Prevents getRegistration() from failing with enumerator
    out of range error (#3835)
- GRPC
  * Fixed: Segmentation fault during murmur shutdown (#3938)
- Client
  * Fixed: Crash when using multiple monitors (#3756)
  * Fixed: Don't send empty message from clipboard via shortcut,
    if clipboard is empty (#3864)
  * Fixed: Talking indicator being able to freeze to indicate talking
    when self-muted (#4006)
  * Fixed: High CPU usage for update-check if update server not
    available (#4019)
  * Fixed: DBus getCurrentUrl returning empty string when not in
    root-channel (#4029)
  * Fixed: Small parts of whispering leaking out (#4051)
  * Fixed: Last audio frame of normal talking is sent to last
    whisper target (#4050)
  * Fixed: LAN-icon not found in ConnectDialog (#4058)
  * Improved: Set maximal vertical size for User Volume Adjustment
    dialog (#3801)
  * Improved: Don't send empty data to PulseAudio (#3316)
  * Improved: Use the SRV resolved port for UDP connections (#3820)
  * Improved: Manual Plugin UI (#3919)
  * Improved: Don't start Jack server by default (#3990)
  * Improved: Overlay doesn't hook into all other processes by
    default (#4041)
  * Improved: Wait longer before disconnecting from a server due
    to unanswered Ping-messages (#4123)
- Server
  * Fixed: Possibility to circumvent max user-count
    in channel (#3880)
  * Fixed: Rate-limit implementation susceptible to
    time-underflow (#4004)
  * Fixed: OpenSSL error 140E0197 with Qt >= 5.12.2 (#4032)
  * Fixed: VersionCheck for SQL for when to use the
    WAL feature (#4163)
  * Fixed: Wrong database encoding that could lead
    to server-crash (#4220)
  * Fixed: DB crash due to primary key violation
    (now performs "UPSERT" to avoid this) (#4105)
  * Improved: The fields in the Version ProtoBuf message are
    now size-restricted (#4101)
- Drop patch add-speechd-include-path.patch, included upstream
* Wed Apr 15 2020 Marcus Rueckert <mrueckert@suse.de>
- use the "profile profilename /path/to/binary" syntax to make
  "ps aufxZ" more readable
* Wed Nov  6 2019 opensuse@trummer.xyz
- set permissions of config file to 640 because it can contain passwords
* Wed Sep 11 2019 Christophe Giboudeaux <christophe@krop.fr>
- Really use the system speex and opus dependencies.
- Run spec-cleaner, use pkgconfig() style BuildRequires when possible.
- Fix the package requirements.
- Remove obsolete conditions and build options.
- Also recommend the Qt mysql and psql backend. Murmur also supports
  those drivers.
* Tue Sep 10 2019 Michal Suchanek <msuchanek@suse.de>
- Update to upstream version 1.3.0 final.
  Release notes at:
    https://www.mumble.info/blog/mumble-1.3.0-release-announcement/
- Use system speex and opus.
* Tue Sep  3 2019 Michal Suchanek <msuchanek@suse.de>
- Update to upstream version 1.3.0-rc2. Supports Qt5. (boo#1148406)
- Remove upstreamed patches:
  - 0001-AudioOutput-do-not-use-non-existant-template-version.patch
  - appdata.patch
  - initialize-soundfile-format.patch
  - mumble-1.2.2-buildcompare.diff
  - mumble-1.2.11-desktop_fix.diff
  - mumble-1.2.19-limit-amount-of-messages.patch
  - mumble-1.2.19-stricter-message-limit.patch
  - mumble-pr-3623-protobuf37.patch
- Refresh add-speechd-include-path.patch
* Fri Jul 12 2019 Ferdinand Thiessen <rpm@fthiessen.de>
- Added patches to fix boo#1123334 (CVE-2018-20743), instability
  and crash due to crafted message flooding
  * added mumble-1.2.19-limit-amount-of-messages.patch (backported
    version of upstream patch)
  * added mumble-1.2.19-stricter-message-limit.patch (backported
    version of upstream patch)
- Cleaned spec file, removed old EOL openSUSE and Fedora versions
* Wed Jun 26 2019 Dirk Mueller <dmueller@suse.com>
- add mumble-pr-3623-protobuf37.patch to fix build against protobuf 3.7
* Wed Jun  5 2019 Ismail Dönmez <idonmez@suse.com>
- Add add-speechd-include-path.patch to fix speechd include paths
- Enable speechd everywhere now
* Sun Apr 14 2019 Christian Boltz <suse-beta@cboltz.de>
- update murmurd AppArmor profile
  - update bash path for usrMerge (boo#1132350)
  - use abstractions/openssl instead of a rule for openssl.cnf
* Fri Oct 19 2018 Marguerite Su <i@marguerite.su>
- build with -std=c++1z on TW since it applies -Wfatal-error that
  conflicts with -std=c++98
* Wed Jan  3 2018 kwalter@suse.com
- Add 0001-AudioOutput-do-not-use-non-existant-template-version.patch
  to fix tumbleweed compilation
* Thu Jun  8 2017 alarrosa@suse.com
- Add initialize-soundfile-format.patch to initilalize a variable so
  it's not used later uninitialized.
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Sun Jan 29 2017 mailaender@opensuse.org
- update to 1.2.19:
  * Murmur’s -limits command will now print output as it runs, instead of at exit.
* Mon Dec 19 2016 dmueller@suse.com
- update to 1.2.18:
  - mostly non-Linux fixes
  - switch default compiler to use C++03
* Sun Sep 25 2016 mailaender@opensuse.org
- Update to version 1.2.17
  * Fixed a bug that could cause the Mumble log view to be
    inacessible after receiving a specially crafted text message.
  * The PulseAudio backend will now fall back to default device
    if the chosen device is no longer present.
  * Mumble now explicitly sends plain text notifications to KDE
    and Freedesktop.org notification endpoints.
  * Xbox button/controller names as shown by Mumble should now be
    correct for controllers other than the first controller.
- Add appdata.patch for https://en.opensuse.org/openSUSE:AppStore
* Fri May 13 2016 rpm@fthiessen.de
- Fixed build on 13.1 by only adding (/var)/run/mumble-server
  as temporary file only on newer openSUSE versions (> 1310)
* Fri May  6 2016 mailaender@opensuse.org
- mumble 1.2.16
  * Mumble will no longer try to poll for changes in XInput button
    state when no controllers are connected.
  * The last references (public server list registration and crash
    reporting) to the old domain name for the Mumble service host,
    “mumble.hive.no”, have been changed to use “mumble.info” instead.
  * The overlay blacklist from 1.3.0 snapshots has been backported.
- add (/var)/run/mumble-server as temporary file for proper cleanup
* Sun Mar 13 2016 astieger@suse.com
- mumble 1.2.15:
  * Add ability to disable the public server list
  * Add ability to create and/or edit Mumble’s server list
- includes changes from 1.2.14:
  * Fix regression crash on exit for in overlay feature
* Mon Jan 11 2016 astieger@suse.com
- mumble 1.2.13:
  * Fix Murmur DoS (Mumble-SA-2016-001), does not affect GNU/Linux
- update upstream signing keyring
* Mon Jan  4 2016 astieger@suse.com
- mumble 1.2.12:
  * The log would always scroll-to-bottom, even if manually
    scrolled up to view a previous message. Scroll-to-bottom is now
    only triggered if the log view has not manually scrolled by the
    user.
  * Fixed a bug where a stale overlay client could cause the Mumble
    UI to freeze under some circumstances.
  * Fixed a bug where CELT and Opus encoders were not properly
    reset when using more than one frame per packet in Mumble. This
    would previously cause noisy artifacts at the beginning of
    transmissions.
* Mon Dec 14 2015 rpm@fthiessen.de
- Removed unneeded patch for SLE10: mumble-1.1.4-sle10glx.diff
- Added patch from RandyBB (roman@priesol.net) to fix missing
  semicolons in desktop file: mumble-1.2.11-desktop_fix.diff
- Removed parts for outdated openSUSE versions, older then openSUSE
  12.2 or SLE 11, from spec file
* Mon Dec 14 2015 astieger@suse.com
- update to 1.2.11:
  * Fixed a bug where Mumble global shortcuts on X11 would not
    release properly when Chrome/Chromium was the frontmost application.
  * Fixed a bug where clients would automatically reconnect after
    being kicked.
  * Inserting an image in the chat should now always cause Mumble
    to scroll correctly to the bottom of the log.
  * Opening mumble:// URLs should now correctly allow people to
    change channels if a URL is opened while Mumble is running.
  * Fixed an issue where the “shortcut/linux/evdev/enable” config
    option was not saved correctly, and overwritten when closing
    Mumble.
* Tue Oct 13 2015 astieger@suse.com
- update to 1.2.10:
  * no code change, other than to create another binary release
    for platforms other than GNU/Linux with updated libraries
* Thu Jun 18 2015 mailaender@opensuse.org
- update to 1.2.9 maintenance release
- remove redundant clean section
- add missing service_add_pre macro
- gpg key has changed
* Wed Mar 18 2015 rpm@fthiessen.de
- Added speech-dispatcher support for openSUSE (Text-To-Speech)
* Mon Mar 16 2015 dimstar@opensuse.org
- Add pkgconfig(speexdsp) BuildRequires: its presence is checked
  for by the build system.
* Thu Feb  5 2015 lnussel@suse.de
- remove gpg-offline from BuildRequires, now done by source validator
  automatically
* Fri Nov 21 2014 lnussel@suse.de
- fix murmur-user-wrapper (bnc#906416)
* Sat Aug  9 2014 mailaender@opensuse.org
- update to 1.2.8
  + A PulseAudio issue that could cause the Mumble client
    to crash on launch has been fixed.
  + Various source-level issues that made the Mumble build
    fail when built with Clang has been fixed.
* Tue Jul 29 2014 mrueckert@suse.de
- fix build for older distros like SLE 11
  - disable xinput2 support on sle 11
  - add a new bcond for systemd and use that throughout the spec
    file for guarding systemd usage instead of spreading out the
    if suse_version conditional all over the place.
  - some systemd pieces were also done on none systemd distros.
    move those into the systemd blocks.
* Sat Jun 14 2014 mailaender@opensuse.org
- update to 1.2.7, minor bugfix
* Thu May 15 2014 lnussel@suse.de
- new bugfix release 1.2.6 fixes security issues (CVE-2014-3756,
  bnc#877971, CVE-2014-3755, bnc#877969)
* Wed Mar 26 2014 lnussel@suse.de
- enable rc link also for systemd
* Thu Feb  6 2014 lnussel@suse.de
- new version 1.2.5 fixes security issues (CVE-2014-0044, CVE-2014-0045,
  bnc#862527)
* Sat Jan 11 2014 adler_187@yahoo.com
- remove syslog.target, since it no longer exists in recent
  systemd versions (>202) and causes the service to fail to start
  (bnc#855478)
* Thu Aug  1 2013 lnussel@suse.de
- clean up old macros
* Thu Jun  6 2013 pascal.bleser@opensuse.org
- update to 1.2.4: http://mumble.sourceforge.net/1.2.4
  Obsoleted patches:
  0001-fix-build-error-with-capability.h.diff
  0001-fix-user-switching.diff
  0001-open-log-file-early-so-log-dir-can-be-root-owned.diff
  0001-if-service-name-is-empty-don-t-pass-an-empty-string.diff
  0001-remove-CAP_NET_ADMIN.diff
  0001-fix-bonjour-support-using-avahi-compat-lib.diff
  mumble-1.2.3-nohardcodedcas.diff
  0001-Explicitly-remove-file-permissions-for-settings-and-D.diff
- systemd service file
* Wed Nov 28 2012 sbrabec@suse.cz
- Verify GPG signature.
* Wed Nov  7 2012 opensuse@cboltz.de
- install apparmor profile without x permissions
* Wed Nov  7 2012 lnussel@suse.de
- require lsb-release (bnc#785659)
* Mon Jun 25 2012 lnussel@suse.de
- allow reading /etc/ssl/openssl.cnf in apparmor profile (bnc#768692)
- fix path to sed and grep due to usr move in 12.2
* Mon Feb 20 2012 lnussel@suse.de
- remove read permissions for other users on local sqlite database
  as it may contain passwords (bnc#747833, CVE-2012-0863)
* Mon Feb 13 2012 lnussel@suse.de
- don't add built-in CA certificates (bnc#660784)
* Wed Jul  6 2011 aj@suse.de
- Use /usr/lib/tmpfiles.d instead of /etc/tmpfiles.d.
* Sat Jun 11 2011 lnussel@suse.de
- install mumble in libdir and put a symlink in bindir to make
  loading libs from applicationDirPath work.
* Mon Apr 11 2011 lnussel@suse.de
- fix bonjour support
* Sun Apr  3 2011 lnussel@suse.de
- fix plugin path
* Thu Mar 24 2011 lnussel@suse.de
- add apparmor profile
* Wed Mar 23 2011 lnussel@suse.de
- fix bonjour registration
* Tue Mar  8 2011 lnussel@suse.de
- change log dir owner to root
- clean up init script
* Mon Feb 21 2011 lnussel@suse.de
- avoid duplicate libcelt libs
* Mon Feb 21 2011 lnussel@suse.de
- new version 1.2.3
  - Improved Voice Activity Detection
  - Customizable Overlay with FPS counter
  - Recording
  - Priority speaker
  - Updated CELT Codec to version 0.11.0
* Thu Jan 27 2011 lnussel@suse.de
- change license tag to BSD3c (bnc#667547)
* Thu Dec 23 2010 lnussel@suse.de
- fix build on sle11sp1
* Wed Dec 15 2010 lnussel@suse.de
- fix some rpmlint warnings
* Fri Jul 16 2010 lnussel@suse.de
- fix crash with long user names (CVE-2010-2490)
* Fri Apr 23 2010 lnussel@suse.de
- actually enable pulseaudio
* Wed Feb 10 2010 lnussel@suse.de
- new version 1.2.2
  * new user information dialog
  * new toolbar
  * Improved connect speed to large servers with lots of users and comments (needs updated server) through use of local caching of content
  * Servers using trusted certificates are now highlighted in green throughout the GUI.
  * CELT version bump; possible quality improvements as a result, on certain configurations
  * LOTRO, L4D2, and ArmA2 plugins
  * Replaced user-textures with avatars to make overlay more useful
  * Better overlay system on Win32 using the pipe method
  * Numerous GUI improvements, including consolidating and reorganizing the main window menus
  * Logitech G15 fixes and improvements
  * Made friend and server window icons skinnable (emblem-favorite.svg, etc, see Skinning)
  * server side database upgrade bug (only occured when updating from 1.1.8 directly to 1.2.1)
  * Bonjour LAN server discovery and resolving works again
  * G15 activation problems
  * memory leak on certain configurations
* Wed Jan 13 2010 lnussel@suse.de
- libcelt must be in /usr/lib/mumble rather than /usr/lib/mumble/plugins
* Sun Jan 10 2010 lnussel@suse.de
- enable ice for fedora 12
* Sun Jan 10 2010 lnussel@suse.de
- add patch to fix 1.1.8 ->  1.2.1 server migration
* Sat Jan  9 2010 lnussel@suse.de
- new version 1.2.0
- add init script and user for server
* Sat Dec 12 2009 lnussel@suse.de
- fix certificate wizard page order for Qt 4.4
* Fri Dec 11 2009 lnussel@suse.de
- new version 1.2.0
* Tue Jul 28 2009 lnussel@suse.de
- fix gcc warning in overlay_gl that causes build failure in Factory
* Mon Mar 30 2009 lnussel@suse.de
- force use of bundled speex on 11.0 to fix build
* Fri Mar 27 2009 lnussel@suse.de
- new version 1.1.8
* Tue Feb 24 2009 lnussel@suse.de
- mark server config as %%config
* Mon Feb 23 2009 lnussel@suse.de
- new version 1.1.7
* Sun Jan 25 2009 lnussel@suse.de
- filter glibc private symbols
- cleanup
* Sat Jan 17 2009 lnussel@suse.de
- add experimental patch to not use mice for shortcuts
* Fri Sep 19 2008 lnussel@suse.de
- new version 1.1.6
* Fri Sep  5 2008 lnussel@suse.de
- enable pulseaudio on openSUSE
- change requirement for 10.3 qt4 bug workaround
* Sat Jun  7 2008 anschneider@suse.de
- support openSUSE 10.2
* Tue May 13 2008 lnussel@suse.de
- new version 1.1.4
  * now with link plugin
* Wed Mar 19 2008 lnussel@suse.de
- split off server package
* Fri Mar 14 2008 lnussel@suse.de
- initial package version 1.1.3
